@@ -17,9 +17,10 @@ put through a deprecation cycle and retracted. After the retraction,
 postfix dereferences will always be recognized. This is the default
 behaviour now.
 
-Starting with version 0.074_01, the first use of this argument will
-warn. With the first release after April 1 2021, all uses will warn.
-After a further six months, all uses will become fatal.
+Starting with version 0.074_01, the first use of this argument warned.
+warn. With version 0.079_01, all uses will warn. With version 0.080_01,
+all uses will become fatal. With the first release on or after April 15
+2022 all mention of this argument will be removed.
 
 =head1 INHERITANCE
 
@@ -197,7 +198,7 @@ use PPIx::Regexp::Util qw{
 use Scalar::Util qw{ refaddr };
 use Text::Tabs ();
 
-our $VERSION = '0.078';
+our $VERSION = '0.081';
 
 =head2 new
 
@@ -927,11 +928,20 @@ L<Regexp::Parser|Regexp::Parser>, which parses a bare regular expression
 navigation model. After a long hiatus, this module has been adopted, and
 is again supported.
 
+L<YAPE::Regex|YAPE::Regex>, which provides the parse tree, and has a
+mechanism to subclass the various element classes for customization. The
+most-recent release is 2011, but the CPAN testers results are still all
+green. Companion module L<YAPE::Regex::Explain|YAPE::Regex::Explain>
+says what the various pieces of a regex do, though constructs added in
+perl 5.10 and later are not supported. I have no idea how I missed this
+when I originally went looking for C<Regexp> parsers.
+
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
-mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
