@@ -48,7 +48,7 @@ use PPIx::Regexp::Constant qw{
 use PPIx::Regexp::Tokenizer;
 use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 
-our $VERSION = '0.076';
+our $VERSION = '0.081';
 
 use constant LOCATION_WIDTH	=> 19;
 
@@ -221,7 +221,7 @@ ignored.
 	    strict => $args{strict},
 	};
 
-	foreach my $key ( qw{ default_modifiers parse postderef } ) {
+	foreach my $key ( qw{ default_modifiers parse } ) {
 	    exists $args{$key}
 		and $self->{$key} = $args{$key};
 	}
@@ -424,7 +424,7 @@ sub _tokens_dump {
 sub _format_default_modifiers {
     my ( $self, $subr, $elem ) = @_;
     my @arg = $self->_safe( $elem );
-    foreach my $attr ( qw{ default_modifiers parse postderef strict } ) {
+    foreach my $attr ( qw{ default_modifiers parse strict } ) {
 	defined ( my $val = $self->{$attr} )
 	    or next;
 	ARRAY_REF eq ref $val
@@ -873,7 +873,9 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -881,7 +883,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
